import 'package:flutter/material.dart';
import 'package:backendless_sdk/backendless_sdk.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  String _status = 'Object is saving to the real time database...';
  String _savedValue = '...';
  Map _savedTestObject;
  IDataStore<Map> _testTableDataStore;
  TextEditingController _controller;

  static const String SERVER_URL = "https://api.backendless.com";
  static const String APPLICATION_ID = "AC9D25EB-6B8D-E53A-FF6B-38E34469C500";
  static const String ANDROID_API_KEY = "AA48CEBC-0A52-40CF-99D1-1548A640EF02";
  static const String IOS_API_KEY = "7A277848-C982-4DB6-BA4F-B3762B4282D4";


  @override
  void initState() {
    super.initState();

    _controller = TextEditingController();

    Backendless.setUrl(SERVER_URL);
    Backendless.initApp(
      APPLICATION_ID,
      ANDROID_API_KEY,
      IOS_API_KEY);

    // create a Map object. This will become a record in a database table
    Map testObject = new Map();

    // add a property to the object. 
    // The property name ("foo") will become a column in the database table
    // The property value ("bar") will be stored as a value for the stored record
    testObject["foo"] = "bar";

    // Save the object in the database. The name of the database table is "TestTable".
    Backendless.data.of("TestTable").save(testObject).then(
    (response) => print("Object is saved in Backendless. Please check in the console."));
    
  }

  void _subscribeForObjectUpdate() {
    _testTableDataStore.rt().addUpdateListener(
      (response) => setState(() => _savedValue = response['foo']),
      whereClause: "objectId='${_savedTestObject["objectId"]}'");
  }

  void _updateValue() {
    _savedTestObject['foo'] = _controller.text;
    _testTableDataStore.save(_savedTestObject).then((response) {
      print("Saved $response");
      _controller.clear();
    });
  }


  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: Padding(padding: EdgeInsets.all(10), child:
      Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text(
              '$_status',
              style: TextStyle(fontSize: 18),
            ),
            Text(
              'Live update object property:',
              style: TextStyle(fontSize: 18),
            ),
            Text(
              '$_savedValue',
              style: Theme.of(context).textTheme.display1,
            ),
            TextField(
              decoration: InputDecoration(
                hintText: 'Change property value'
              ),
              controller: _controller,
            ),
            RaisedButton(
              child: const Text('Update'),
              color: Colors.white54,
              
              onPressed: _updateValue,
            ),
          ],
        ),
      ),
    ));
  }
}
				